summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authordes <des@FreeBSD.org>2001-12-04 01:10:34 +0000
committerdes <des@FreeBSD.org>2001-12-04 01:10:34 +0000
commit8cabee0ca4ac41ae057d025599157d29c5a40b05 (patch)
treed895fd94cdd748608699abfbcdb61d5f11962d75 /lib
parent5d89c5ae6e3756159ce326b909361e584d15738b (diff)
downloadFreeBSD-src-8cabee0ca4ac41ae057d025599157d29c5a40b05.zip
FreeBSD-src-8cabee0ca4ac41ae057d025599157d29c5a40b05.tar.gz
Add prototype for _ftp_request().
Diffstat (limited to 'lib')
-rw-r--r--lib/libfetch/common.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/lib/libfetch/common.h b/lib/libfetch/common.h
index f869eb8..6dad684 100644
--- a/lib/libfetch/common.h
+++ b/lib/libfetch/common.h
@@ -65,16 +65,20 @@ int _fetch_add_entry(struct url_ent **, int *, int *,
#endif
/*
* I don't really like exporting _http_request() from http.c, but ftp.c
* occasionally needs to use an HTTP proxy, and this saves me from adding
* a lot of special-case code to http.c to handle those cases.
*
- * Note that _http_request() frees purl, which is way ugly but saves us a
+ * Note that _*_request() free purl, which is way ugly but saves us a
* whole lot of trouble.
*/
FILE *_http_request(struct url *, const char *,
struct url_stat *, struct url *,
const char *);
+FILE *_ftp_request(struct url *, const char *,
+ struct url_stat *, struct url *,
+ const char *);
/*
* Check whether a particular flag is set
OpenPOWER on IntegriCloud
@@ -65,16 +65,20 @@ int _fetch_add_entry(struct url_ent **, int *, int *,
#endif
/*
- * I don't really like exporting _http_request() from http.c, but ftp.c
- * occasionally needs to use an HTTP proxy, and this saves me from adding
- * a lot of special-case code to http.c to handle those cases.
+ * I don't really like exporting _http_request() and _ftp_request(),
+ * but the HTTP and FTP code occasionally needs to cross-call
+ * eachother, and this saves me from adding a lot of special-case code
+ * to handle those cases.
*